@@ -20,15 +20,15 @@
 
 #include <bakery/App/App_WithDoc_Gtk.h>
 #include <bakery/App/GtkDialogs.h>
-#include <libgnomevfsmm/utils.h> //For escape_path_string()
-#include <libgnomevfsmm/mime-handlers.h> //For type_is_known(). 
+//#include <libgnomevfsmm/utils.h> //For escape_path_string()
+//#include <libgnomevfsmm/mime-handlers.h> //For type_is_known(). 
 #include <gtkmm/toolbutton.h>
 #include <gtkmm/stock.h>
 #ifdef GTKMM_GEQ_2_10
 #include <gtkmm/recentchoosermenu.h>
 #endif // GTKMM_GEQ_2_10
 #include <algorithm>
-#include <libintl.h>
+#include <glibmm/i18n-lib.h>
 
 //#include <gtk/gtkfilesel.h>
 
@@ -41,8 +41,7 @@ namespace Bakery
 
 App_WithDoc_Gtk::App_WithDoc_Gtk(const Glib::ustring& appname)
 : App_WithDoc(appname),
-  App_Gtk(appname),
-  m_deprecated_recent_files_model(0)
+  App_Gtk(appname)
 {
 }
 
@@ -50,8 +49,7 @@ App_WithDoc_Gtk::App_WithDoc_Gtk(const Glib::ustring& appname)
 App_WithDoc_Gtk::App_WithDoc_Gtk(BaseObjectType* cobject, const Glib::ustring& appname)
 : App_WithDoc(appname),
   App_Gtk(cobject, appname),
-  ParentWindow(cobject), //This is a virtual base class (not a direct base), so we must specify a constructor or the default constructor will be called, regardless of what the App_Gtk(cobject) constructor does. Derived classes must do this as well.
-  m_deprecated_recent_files_model(0)
+  ParentWindow(cobject) //This is a virtual base class (not a direct base), so we must specify a constructor or the default constructor will be called, regardless of what the App_Gtk(cobject) constructor does. Derived classes must do this as well.
 {
   //TODO: appname.
 }
@@ -103,18 +101,20 @@ void App_WithDoc_Gtk::init_menus_file_recentfiles(const Glib::ustring& path)
       for(type_list_strings::iterator iter = m_mime_types.begin(); iter != m_mime_types.end(); ++iter)
       {
         const Glib::ustring mime_type = *iter;
-#ifndef G_OS_WIN32
-        if( Gnome::Vfs::Mime::type_is_known(mime_type) )
-#endif // !G_OS_WIN32
-        {
+
+        //TODO: Find a gio equivalent for gnome_vfs_mime_type_is_known(). murrayc.
+//#ifndef G_OS_WIN32
+//        if( Gnome::Vfs::Mime::type_is_known(mime_type) )
+//#endif // !G_OS_WIN32
+//        {
           filter.add_mime_type(mime_type);
-        }
-#ifndef G_OS_WIN32
-        else
-        {
-          g_warning("App_WithDoc_Gtk::init_menus_file_recentfiles(): MIME-type %s is not known to gnome-vfs", mime_type.c_str());
-        }
-#endif // !G_OS_WIN32
+//        }
+//#ifndef G_OS_WIN32
+//        else
+//        {
+//          g_warning("App_WithDoc_Gtk::init_menus_file_recentfiles(): MIME-type %s is not known to gnome-vfs", mime_type.c_str());
+//        }
+//#endif // !G_OS_WIN32
       }
 
       Gtk::RecentChooserMenu* menu = Gtk::manage(new Gtk::RecentChooserMenu);
@@ -147,8 +147,8 @@ void App_WithDoc_Gtk::init_menus_file()
   //Build actions:
   m_refFileActionGroup = Gtk::ActionGroup::create("BakeryFileActions");
 
-  m_refFileActionGroup->add(Gtk::Action::create("BakeryAction_Menu_File", gettext("_File")));
-  m_refFileActionGroup->add(Gtk::Action::create("BakeryAction_Menu_File_RecentFiles", gettext("_Recent Files")));
+  m_refFileActionGroup->add(Gtk::Action::create("BakeryAction_Menu_File", _("_File")));
+  m_refFileActionGroup->add(Gtk::Action::create("BakeryAction_Menu_File_RecentFiles", _("_Recent Files")));
 
   //File actions
   m_refFileActionGroup->add(Gtk::Action::create("BakeryAction_File_New", Gtk::Stock::NEW),
@@ -224,7 +224,7 @@ void App_WithDoc_Gtk::update_window_title()
 
     //Indicate read-only files:
     if(pDoc->get_read_only())
-      strTitle += gettext(" (read-only)");
+      strTitle += _(" (read-only)");
 
     set_title(strTitle);
   }
