@@ -19,9 +19,9 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <libintl.h>
-
+#include "config.h"
 #include "appexample.h"
+#include <glibmm/i18n.h>
 
 AppExample::AppExample()
   : Bakery::App_Gtk("WithoutDoc"),
@@ -40,7 +40,7 @@ void AppExample::init()
 {
   type_vecStrings vecAuthors;
   vecAuthors.push_back("Murray Cumming <murrayc@usa.net>");
-  set_about_information("0.1", vecAuthors, gettext("(C) 2000 Murray Cumming"), gettext("A Bakery example"));
+  set_about_information("0.1", vecAuthors, _("(C) 2000 Murray Cumming"), _("A Bakery example"));
 
   //Call base method:
   Bakery::App_Gtk::init();
